Monty Python's Flying Circus: Just the Words - Episode 36

# Episode Thirty-six

Tudor job agency
Pornographic bookshop
Silly disturbances (the Rev. Arthur Belling)
The free repetition of doubtful words sketch, by an underrated author
'Is there?'...life after death?
The man who says words in the wrong order
Thripshaw's disease
Silly noises
Sherry-drinking vicar

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Outside a shop. A sign reads 'Tuder Job Agency - Jobs a Speciality'. A man enters the shop. Inside it is decorated in Tudor style. The assistant is in Tudor dress.
Assistant | Morning, sir, can I help you?
Customer | Yes, yes... I wondered if you have any part-time vacancies on your books.
Assistant | Part-time, I'll have a look, sir. (he gets out a book and looks through it) Let me look now. We've got, ah yes, Sir Walter Raleigh is equipping another expedition to Virginia; he needs traders and sailors. Vittlers needed at the Court of Philip of Spain, oh, yes, and they want master joiners and craftsmen for the building of the Globe Theatre.
Customer | I see. Have you anything a bit more modern, you know, like a job on the buses, or digging the underground?
Assistant | Oh no, we only have Tudor jobs.
Customer | That can't be very profitable, can it?
Assistant | Well, you'd be surprised, actually sir. The Tudor economy's booming, ever since Sir Humphrey Gilbert opened up the Northwest passage to Cathay, and the Cabots' expansion in Canada, there's been a tremendous surge in exports, and trade with the Holy Roman Empire is going... no, quite right, it's no good at all.
Customer | What?
Assistant | It's a dead loss. We haven't put anyone in a job since 1625.
Customer | I see.
Assistant | That's all?
Customer | What?
Assistant | That's all you say?
Customer | Yes.
Assistant | No, no, we were the tops then. Drake got all his sailors here. Elizabeth, we supplied the archbishops for her coronation. Shakespeare started off from here as a temp. Then came James the First and the bottom fell out of the Tudor jobs. 1603 - 800 vacancies filled, 1604 - 40, 1605 - none, 1606 - none. The rest of the Stuart period nothing. Hanoverians nothing. Victorians nothing. Saxe-Coburgs nothing. Windsors... what did you want?
Customer | Dirty books, please.
Assistant | Right. (produces selection of mags from under counter) Sorry about the Tudor bit, but you can't be too careful, you know. Have a look through these.
Customer | Have you got anything a bit... er...
Assistant | A bit stronger?
Customer | Yes.
Assistant | Hold on ... a... My Lord of Warwick!
Second Assistant | (off) 'Allo!
Assistant | Raise high the drawbridge. Gloucester's troops approach.
Second Assistant | (off) Right.
Assistant | Can't be too careful you know, sir.
| The wall of the Tudor shop slides back to reveal the interior of a Soho dirty bookshop in the back room - a bare room with a counter and magazines in racks on the walls at eye-level. Three drably dressed men are thumbing through books. One of them is a vicar, one of them is gathering a huge pile. Behind the counter is a Soho toughie in Tudor gear showing books to Mr Nid - a tweedy, rather academic, respectable-looking man of senior years. The customer goes through, and the wall slides back.
Second Assistant | There's a 'Bridget - Queen of the Whip'.
Nid | Yes...
Second Assistant | Or 'Naughty Nora'... or there's this one: 'Doug, Bob and Gordon Visit the Ark Royal'. Or there's 'Sister Teresa - The Spanking Nun'.
Nid | Mmmm... I see ... you don't have anything specially about Devon and Cornwall?
Second Assistant | No. I'm afraid not, sir.
Nid | The one I was really after was Arthur Hotchkiss's 'Devonshire Country Churches'.
Second Assistant | Well how about this, sir: 'Bum Biters'.
Nid | No ... not really ... I don't suppose you have any general surveys of English Church architecture?
Second Assistant | No, it's not really our line, sir.
Nid | No, I see. Well, never mind I'll just take the 'Lord Lieutenant in Nylons' then, and these two copies of 'Piggie Parade'. Thank you.
Second Assistant | Right, sir.
First Assistant | (voice over) My Lord of Warwick.
Second Assistant | 'Allo?
First Assistant | (voice over) Raise high the drawbridge. Gloucester's troops approach!
Second Assistant | Right.
| He presses a button below counter and the wall slides back. The man with the big pile of books comes up to counter.
Man | Just these, then.
| Enter Gaskell in Tudor gear. The wall closes up behind him.
Gaskell | All right. This is a raid. My name is Superintendent Gaskell and this is Sergeant Maddox.
Second Assistant | Ah! Sir Philip Sidney. 'Tis good to see thee on these shores again.
Gaskell | Shut up.
Second Assistant | Your suit is fair and goodly cut. Was't from Antwerp?
Gaskell | Shut up. It's a disguise. Right! Confiscate the smutty books, Maddox.
Second Assistant | Sir Philip!. Prithee nay!
Gaskell | Listen, mate! Don't come that Philip Sidney bit with me. I'm not a bloody Tudor at all. I'm Gaskell of the Vice Squad and this is Sergeant Maddox.
| They all look at him blankly. He looks to Maddox for support and realizes he isn't there.
Gaskell | Maddox! Where's he gone?
Second Assistant | Sir Philip, prithee rest awhile.
Gaskell | Look. This is the last time. I'm warning you, I'm not Sir Philip Bleeding Sidney. I am Superintendent Harold Gaskell and this is a raid.
| Everybody resumes their book-buying and ignores him. At the counter the assistant is still totting up the huge pile of books.
Second Assistant | That'll be 540 quid sir.
Man | Oh, I'll just have this one then. (takes top one)
Gaskell | Maddox! (addressing everyone in shop; they ignore him) Look, this is a raid. (no reaction) Honestly, I promise you. (people start to leave through the rear door of the shop; Gaskell blocks it) Where are you going?
Customer | I'm going home.
Gaskell | Right. (looks for his notebook but it's not in his Tudor clothing) I'll remember you. Don't you worry. I'll remember you...
Customer | Pray good, Sir Philip, that you...
Gaskell | Don't you start! Maddox! (the customer leaves; other customers start to leave) Listen, I can prove to you I'm a policeman. I can give the names of all the men down in 'F' division at Acton: Inspector Arthur Perry, Superintendent Charles Frodwell, my best friend, police dogs, Batch, Wolf, Panther, Maudling. How would I know those names if I was Sir Philip Sidney? (the vicar comes up to counter) Look, vicar, you know me. The Gargoyle Club - I got you off the charge. (the vicar leaves guiltily)
Second Assistant | Farewell, good Sir Philip.
| He goes out carrying a pile of magazines. Then the vicar goes, followed by the Tudor man.
Gaskell | Hey, stop! (the door slams; Gaskell turns and looks round the empty shop; pause) Maddox!
| He rushes up to the sliding wall and beats on it. Then he turns and makes for the little back door and goes through.
Gaskell | You'll never get away with this, you porn merchant. Blimey!
| He stops and gapes. We cut to his eye-line to see he is standing in a beautiful, green, Tudor garden. In the distance a Tudor house. A girl is sitting on a stone bench, sobbing. Gaskell walks towards her, bewildered.
Gaskell | Maddox!
| The girl looks up at him with beseeching eyes. She is young and beautiful.
Girl | Oh good sir, how glad I am to see thee come. Forgive me weeping, but my love has gone.
Gaskell | Er, listen. My name is Caskell ... Superintendent Caskell of Vice Squad. Myself and Sergeant Maddox are on a raid. We are not Tudor people. We are the police.
| An Elizabethan gentleman appears through the trees.
Father | Frances, what idleness is this? Why, good Sir Philip Sidney, (he bows extravagantly to Gaskell) What hast thee here?
Girl | (turning to Caskell with bated breath) You are Sir Philip Sidney?
Gaskell | ... Possibly... but I may be Superintendent Gaskell of the Vice Squad.
Father | Ah good, Sir Philip, thy sharp-tongued wit has not deserted thee. Come. Let us eat and drink. Stay with us awhile.
Gaskell | All right, sir. I think I will.
| They walk off together arm in arm into the idyllic country garden. The girl looks after them with hope in her eyes. Bring up Elizabethan music.
| SUPERIMPOSED CAPTION: 'THE LIFE OF SIR PHILIP SIDNEY'
| Mix through to a Tudor dining room. At the table a group of Tudor gentry are sitting listening to Gaskell. Evidence of a banquet, and two minstrels in attendance. Gaskell has obviously just finished a story. Applause and laughter.
Gaskell | . .. then did we bust the Harry Tony mob, who did seek to import Scandinavian filth via Germany. For six years they cleaned up a packet - the day I got whiff of them through a squealer and within one week did a mop-up right good. They're now languishing doing five years bird in Parkhurst.
| Applause. They are all very impressed. Cut to exterior. A messenger on a horse rides full pelt straight towards the camera. It is dusk. He stops outside the Elizabethan house, leaps off and dashes into the house. Cut to interior again. They are still all laughing from his last story. The messenger bursts into room.
Messenger | Sir Philip. The Spaniards have landed in the Netherlands. My Lord Walsingham needs you there forthwith.
Gaskell | Let's go.
| Cut to exterior. Gaskell is seated on the back of the messenger's horse and they gallop off. The dinner crowd are standing waving on the doorstep.
Dinner Crowd | Good luck, Sir Philip!
| Cut to a British standard fluttering in the breeze against the blue sky. Fanfare. Two Elizabethan gentlemen, and four men dressed as Elizabethan soldiers are standing on a cliff top. Gaskell strides up to them, and takes up position on topmost point of the knoll.
Gaskell | Where are the Spaniards?
Elizabethan Gent | Down below Sir Philip, their first boats are landing even now.
| Shot of a sailing-galley seen from above.
Gaskell | Right, you stay here, I'll go and get them.
Elizabethan Gent | Sir Philip! Not alone!
| Cut to the beach. Suspense music. Gaskell strides up to the camera, until he is towering over it. The music reaches crescendo.
Gaskell | Allo allo! What's going on here?
| Cut to beached rowing boat piled high with bundles of dirty magazines. Two Spaniards are unloading it.
Spaniard | Ees nothing, Señor, ees just some literature.
Gaskell | I know what literature is, you dago dustbin. I also know what porn is. (pulls out a loose magazine and brandishes it) What's this then eh?
Spaniard | It is one of Lope De Vega's latest play, Señor.
Gaskell | 'Toledo Tit Parade'? What sort of play's that?
Spaniard | It's very visual, Señor.
Gaskell | Right. I'm taking this lot in the name of Her Gracious Majesty Queen Elizabeth.
Spaniard | Oh, but Señor.
Gaskell | Don't give me any trouble. Just pile up these baskets of filth and come with me.
| The second Spaniard leaps out of the boat with a drawn sword and they both engage Gaskell in a fight. Then we start to draw away from them, leaving them tiny dots in the distance fighting. Fight music over all this and voice over.
Voice Over | The battle raged long and hard, but as night fell Sidney overcame the Spaniards. 6,000 copies of 'Tits and Bums' and 4,000 copies of 'Shower Sheila' were seized that day. The tide of Spanish porn was stemmed. Sir Philip Sidney returned to London in triumph.
| Cut to stock film of Elizabethan London street during celebrations.
| SUPERIMPOSED CAPTION: 'LONDON 1583'
| Cut to side on close up of Gaskell riding hard through woodland.
Voice Over | Covered in glory, Sir Philip rode home to Pensburst to see his beloved wife... but all was not well.
| Gaskell runs up outside another Tudor house and strides in. Cut to interior of an Elizabethan room - panelled walls, log fire, latticed windows, etc. Sir Philip's wife is sitting reading. Gaskell enters.
Gaskell | Good evening all, my love. I have returned safe from the Low Countries. (she hurriedly hides the book she is reading under some knitting and starts whistling) What are thou reading, fair one?
Wife | Oh, 'tis nothing, husband.
Gaskell | I can see 'tis something.
Wife | 'Tis one of Shakespeare's latest works.
| Gaskell picks up the book and reads the title.
Gaskell | Oh ...'Gay Boys in Bondage' What, is't - tragedy? Comedy?
Wife | 'Tis a... er... 'tis a story of a man's great love for his... fellow men.
Gaskell | How fortunate we are indeed to have such a poet on these shores.
Wife | Indeed. How was the war, my lord?
Gaskell | The Spaniards were defeated thrice. Six dozen chests of hardcore captured.
Wife | (trying to look innocent) Hast brought home any spoils of war?
Gaskell | Yes, good my wife, this fair coat trimmed with ermine.
Wife | (without enthusiasm) Oh, lovely, nowt else?
Gaskell | No, no fair lady. The rest was too smutty.
| He settles himself down in front of his lady's feet and the fire.
Gaskell | Now, my good wife. Whilst I rest, read to me a while from Shakespeare's 'Gay Boys in Bondage'.
| The wife looks a trifle taken aback but reluctantly opens the book and starts to read with a resigned air.
Wife | Yes... my lord ... 'Gay Boys in Bondage' ... Ken, 25, is a mounted policeman with a difference... and what a difference. Even Roger is surprised and he's... (she looks slightly, sick with guilt) he's used to real men ...
Gaskell | 'Tis like 'Hamlet' ... what a genius!
Wife | 'But who's going to do the cooking tonight? Roddy's got a mouthful...'
| Enter Maddox - a modern-day plain-clothed policeman.
Maddox | All right, this is a raid.
| The wife screams, Gaskell leaps to his feet.
Wife | Oh! We are disgraced!
Gaskell | There you are, Maddox!
Maddox | Cut the chat... and get in the van.
Gaskell | Maddox! You recognize me...
Maddox | Indeed I do, Sir Philip Sidney, and sad I am to see you caught up in this morass of filth, (he picks up the book) ooh - that's a long one.
Wife | Oh oh... the glorious name of Sidney is besmirched ... all is lost ... oh alas the day.
Gaskell | Shut up! I know this man - this is my old mate Sergeant Maddox...
Maddox | You'll do time for this.
Gaskell | Oh Maddox - it's me - Gaskell ... 'F' division down at Acton ... Inspector Arthur Frodwell.
Maddox | Come on Sidney. (he bundles them both out) And you, miss.
Gaskell | I'm not Sir Philip bleedin' Sidney .... and where were you? We could have mopped up that Tudor shop...
| They are bundled out. Maddox pauses only to pick a book from the bookcase near the door.
Maddox | Ooh! That's a good one!
| Cut to outside a modern theatre stage-door. Gaskell, still protesting, and Mrs Sidney are bundled out and into a police van. As it drives off, it reveals on the side of the theatre a poster saying 'The Aldwych Theatre, The Royal Shakespeare Company Presents 'Gay Boys In Bondage' By William Shakespeare'. An animated excerpt from this little known Shakespearian masterpiece leads us to a table outside a restaurant. A young couple are sitting blissfully at it.
She | It's nice here, darling, isn't it.
He | It's beautiful, it's Paris all over again.
| Enter a vicar, dressed normally but has bald wig with fright hair at sides. He carries a suitcase.
Vicar | Excuse me, do you mind if I join you?
He | Er, no... no... no... not at all.
Vicar | Are you sure you don't mind?
He | Yes, yes, absolutely.
Vicar | You're sure I won't be disturbing you?
He | No, no.
Vicar | You're absolutely sure I won't be disturbing you?
She | No, no really.
Vicar | Good. Because I don't want to disturb you. Specially as you're being so kind about me not disturbing you.
He | Oh, no, no, we don't mind, do we, darling?
She | Oh no, darling.
Vicar | Good, so I can go ahead and join you then? Can I?
Both | Yes ... yes...
Vicar | Won't be disturbing?
Both | No. No.
Vicar | Good, good. You're very kind. (he sits down) A lot of people are far less understanding than you are. A lot of people take offense even when I talk to them. (he makes strange gestures with his hands) Let alone when I specifically tell them about my being disturbing.
He | ... Well, it's not particularly disturbing.
Vicar | No, absolutely, absolutely, that's what I always say. (he produces plates from his case and smashes them on the table) But you'd be amazed at the number of people who really don't want me - I mean, even doing this (he produces a rubber crab suspended from a ping-pong paddle and a rubber baby doll and bobs them up and down, making loud silly noises as he does so) gets people looking at me in the most extraordinary way. (he breaks more plates and squirts shaving cream over his head; he and she get up to leave)
He | We must be getting on.
Vicar | I knew I'd disturb you ... I knew I'd disturb you ... (miserably) It always happens ... whenever I've found someone I really think I'm going to be able to get on with...
He | No, the only thing is, you see, we're going to be a little bit late.
She | (sitting down and comforting vicar) Let's stay.
He | Well, just a little bit... I mean, we will be late if we don't... (he sits down reluctantly)
Vicar | Oh, thank you. You're very kind.
| More silly behaviour from the vicar. He and she look embarrassed. Dissolve to them sitting at home smashing plates, making silly noises and covering themselves with shaving cream.
She | (voice over) As it turned out our chance meeting with Reverend Arthur Belling was to change our whole way of life, and every Sunday (film of them running into a church) we'd hurry along to St Loony up the Cream Bun and Jam.
| Hold shot of the church. Sound of a congregation standing. We hear the silly noises. Cut to nude organist (Terry J). He plays a fanfare.
Announcer | And now...
It's Man | It's...
| Animated titles. Straight into animated sketch, ending with:
Voice Over | (and CAPTION) 'THE FREE REPETITION OF DOUBTFUL WORDS - SKIT, SPOOF, JAPE OR VIGNETTE, BY A VERY UNDER-RATED WRITER'
| A post office counter window, with 'Telegram Enquiries' over the top. We see this through an ornate vignette. The clerk is behind the counter. Enter Mr Peepee. They speak very stiltedly.
Peepee | I've come for some free repetition of doubtful words on an inland telegram.
Clerk | Have you got the telegram in question?
Peepee | I have the very thing here.
Clerk | Well, slip it to me my good chap and let me eye the contents.
Peepee | At once Mr Telegram Enquiry Man.
Clerk | Thank you Mr Customer Man. (reads) Aha. 'Parling I glove you. Clease clome at bronce, your troving swife, Pat.' Which was the word you wanted checking?
Peepee | Pat.
Clerk | Pat?
Peepee | My wife's name is not Pat at all.
Clerk | No?
Peepee | It's Bat. With a B.
Clerk | And therefore I will take a quick look in the book.
Peepee | Ripping.
| CAPTION: 'ONE QUICK LOOK IN THE BOOK LATER'
Clerk | You're quite right, old cock. There has been a mistake.
Peepee | I thought as much. What really does it say?
Clerk | It say 'Go away you silly little bleeder. I am having another man. Love Bat'. Quite some error.
Peepee | Yes. She wouldn't call herself Pat, it's silly.
Clerk | Daft, I call it.
Peepee | Well it has been a pleasure working with you.
Clerk | For me also it has been a pleasure. And that concludes our little skit.
| String quartet music starts to play, as at the beginning, only this time we widen to reveal a string quartet sitting in the set, playing. The clerk and Peepee adopt slightly frozen position. Mix to:
Voice Over | (and CAPTION:) 'THE FREE REPETITION OF DOUBTFUL WORDS THING, BY A JUSTLY UNDERRATED WRITER - THE END'
| Animation link to a late-night religious-type discussion. A chairman and three guests are slumped motionless in their seats.
Roger Last | Good evening. Tonight on 'Is There' we examine the question, 'Is there a life after death?'. And here to discuss it are three dead people... The late Sir Brian Hardacre, former curator of the Imperial War Museum ... (superimposed captions identify them) the late Professor Thynne, until recently an academic, critic, and broadcaster ... and putting the view of the Church of England, the very late Prebendary Reverend Ross. Gentlemen, is there a life after death or not? Sir Brian? (silence) Professor? ... Prebendary?.... Well there we have it, three say no. On 'Is There' next week we'll be discussing the question 'Is there enough of it about?', and until then, goodnight.
| SUPERIMPOSED CREDITS: 'IS THERE' INTRODUCED BY ROGER LAST RESEARCH: J. LOSEY L. ANDERSON S. KUBRICK P. P. PASOLINI O. WELLES THE LATE B. FORBES PRODUCED BY: GILLIAN (AGED 3 l/2)
| Under these credits, we see the stiffs being carried off by people. Cut to a doctor's surgery. The doctor has in front of him a plaque which says 'Dr E. H. Thripshaw'. Enter Burrows.
Burrows | Good doctor morning! Nice year for the time of day!
Thripshaw | Come in.
Burrows | Can I down sit?
Thripshaw | Certainly. (Burrows sits) Well, then?
Burrows | Well, now, not going to bush the doctor about the beat too long. I'm going to come to point the straight immediately.
Thripshaw | Good, good.
Burrows | My particular prob, or buglem bear, I've had ages. For years, I've had it for donkeys.
Thripshaw | What?
Burrows | I'm up to here with it, I'm sick to death. I can't take you any longer so I've come to see it.
Thripshaw | Ah, now this is your problem with words.
Burrows | This is my problem with words. Oh, that seems to have cleared it. 'Oh I come from Alabama with my banjo on my knee'. Yes, that seems to be all right. Thank you very much.
Thripshaw | I see. But recently you have been having this problem with your word order.
Burrows | Well, absolutely, and what makes it worse, sometimes at the end of a sentence I'll come out with the wrong fusebox.
Thripshaw | Fusebox?
Burrows | And the thing about saying the wrong word is a) I don't notice it, and b) sometimes orange water given bucket of plaster.
Thripshaw | Yes, tell me more about your problem.
Burrows | Well as I say, you'd just be talking and out'll pudenda the wrong word and ashtray's your uncle. So I'm really strawberry about it.
Thripshaw | Upset?
Burrows | It's so embarrassing when my wife and I go to an orgy.
Thripshaw | A party?
Burrows | No, an orgy. We live in Esher.
Thripshaw | Quite.
Burrows | That's what I said. Such a bloody whack the diddle fa di la, fo di la, lo do di ... do di do, rum fum.
Thripshaw | Mr Burrows, this is no common problem. You are suffering from a disease so rare that it hasn't got a name. Not yet. But it will have. Oh yes. This is the opportunity I've been waiting for. The chance of a lifetime! (zoom in to close up on him as lighting changes to dramatic spotlight) I'll show them at the Royal College of Surgeons! I'll make them sit up and take notice! Thripshaw's disease! Discovered by E. Henry Thripshaw MD! I'll be invited on 'Call My Bluff' and the merchandizing, there'll be E. Henry Thripshaw t-shirts ... I'll turn it into a game ... I'll sell the film rights.
| Cut to front of a booklet, entitled 'A Dissertation on Thripshaw's Disease Presented to the Royal College of Surgeons by Dr f. Henry Thripshaw'. Captions zoom forward over it:
| HARLEY STREET FLEET STREET BROADWAY HOLLYWOOD
| A page of the book turns to reveal the title 'David O. Seltzer Presents'. The page turns again to reveal 'Rip Glint in:'. The page turns again to reveal a title in stone lettering a la Ben-Hur, with searchlights behind a la 20th-Century Fox: 'Dr E. Henry Thripshaw's Disease'. Cut to stock film of marauding knights.
| SUPERIMPOSED CAPTION: 'SYRIA 1203'
| The knights sack a village, looting, pillaging, burning and murdering. Cut to a studio set with interviewer and Thripshaw.
Interviewer | (speaking with frequent pauses, as of one reading from a slow autocue) That clip... comes from the new David O. Seltzer... film. The author... of that film clip ... is with me ... now. Doctor E. Henry ... Thripshaw.
Thripshaw | Well, I feel that they have missed the whole point of my disease.
Interviewer | This is .... always the problem ... with directors of film... clips.
Thripshaw | Yes, well you see, they've dragged in all this irrelevant mush...
Interviewer | What... are you doing ... now?
Thripshaw | Well at the moment I am working on a new disease, which I hope to turn into a musical, but, primarily we are working on a re-make of my first disease and this time we're hoping to do it properly.
Interviewer | Well ... let's just ... take a ... look at this new film...clip.
| Film clip exactly as before. Cut to Thripshaw at a desk evidently in a castle. A knight in armor rushes up to him.
Thripshaw | Well now, what seems to be the matter?
| Cut to a corner of the set where a man emerges from a barrel.
Man | The next sketch starts after some silly noises.
| Black screen and a collection of really silly noises. Then fade up on a country church. Cut to interior, a vestry. A sign reads 'No Papists'. The door opens and the vicar enters as if from the end of a service. He takes off his cassock and is hanging it up. At one side of the set is a sculpture on a plinth. It is the vicar's head, but with an enormously long nose. Mr Kirkham has followed the vicar in. He is an earnest, quiet, self-effacing soul, with a tortured conscience.
Vicar | Come in.
Kirkham | I wondered if I could have a word with you for a moment.
Vicar | By all means ... by all means, sir. Do sit down. (they look round for a chair) Ah, sit on the desk here.
Kirkham | Thank you.
Vicar | Now then, a glass of sherry?
Kirkham | No... no thank you...
Vicar | (getting a bottle from the cupboard) Are you sure? I'm going to have some.
Kirkham | Well, if you're having some, yes then, perhaps, vicar.
Vicar | (slightly taken aback) Oh... well there's only just enough for me.
Kirkham | Well in that case I won't, don't worry.
Vicar | You see, if I split what's left, there'd be hardly any left for me at all.
Kirkham | Well, I'm not a great sherry drinker.
Vicar | Good! So, I can have it all ... now then what's the problem?
Kirkham | Well, just recently I've begun to worry about...
| The vicar has been looking through his desk. He produces a bottle of sherry in triumph.
Vicar | Ah! I've found another bottle! You can have some now if you want to.
Kirkham | Well... yes, perhaps a little...
Vicar | Oh you don't have to. I can drink the whole bottle.
Kirkham | Well in that case, no...
Vicar | Good! That's another bottle for me. Do go on.
| The vicar opens the bottle and pours himself a glass. As soon as he has drunk it he replenishes it again.
Kirkham | I've begun to worry recently that...
| There is a knock on the door.
Vicar | Come in!
| A smooth man, Mr Husband, enters carrying a smart little briefcase.
Vicar | Ah, Mr Husband ... this is Mr Kirkham, one of my parishioners, this is Mr Husband of the British Sherry Corporation...
Kirkham | Look, look, perhaps I'd better come back later...
Vicar | No, no ... no do stay here. Have a sherry... you won't be long will you, Husband?
Husband | Oh no, vicar... it's just a question of signing a few forms.
| The vicar pours Husband a sherry.
Vicar | There we are... there we are, Mr Husband. Now, how about you, Mr Kirkham?
Kirkham | Well only if there's enough.
Vicar | Oh well, there's not much now.
Kirkham | Oh, in that case... no... I won't bother.
Vicar | (pouring himself one) Good. Right... now, then, what is the problem, Husband?
Husband | Well, vicar, I've made enquiries with our shippers and the most sherry they can ship in any one load is 12,000 gallons.
Vicar | And how many glasses is that?
Husband | That's roughly 540,000 glasses, Vicar.
Vicar | That's excellent, Husband, excellent.
Husband | Yes... it means you can still keep your main sherry supply on the roof, but you can have an emergency supply underneath the vestry of 5,000 gallons.
Vicar | Yes... and I could have dry sherry on the roof and Amontillado in the underground tank!
Husband | Absolutely.
| The vicar signs a form that Husband hands to him.
Vicar | Excellent work, Husband, excellent work.
Husband | Not at all, vicar, you're one of our best customers... you and the United States. Well goodbye. (he leaves)
Vicar | Terrific. Now then, Mr Kirkham (pouring himself anothter sherry) I am so sorry... do go on.
Kirkham | Well, it's just that recently I've begun to worry about...
Vicar | Well, look...
Kirkham | I sometimes ask myself - does the Bible intend...
| A group of Spanish singers in full national costumes with guitars bursts into the Vestry, noisily singing a song praising Amontillado. A man in an extravagant Spanish costume rushes in. His hat has a sign on it saying: 'Sherry, the drink of champions'. Two girls come in bearing maracas and Carmen Miranda style hats. Mr Kirkham looks fed up. The Spaniards finish their song, noisily.
Man | What did you want?
Vicar | Dirty books, please.
| As they carry out their transactions, noisily, we cut to the credits, rolled over a shot of the dirty postcards scetion of the Tudor dirty bookshop. The credits read:
| 'MONTY PYTHON'S FLYING CIRCUS (with 'censored' notice over it) WAS CONCIEVED, WRITTEN AND CENSORED BY MICHAEL 'BULKY' PALIN TERRY JONES 'KING OF THE LASH' JOHN CLEESE 'A SMILE, A SONG AND A REFILL' TERRY GILLIAM 'AN AMERICAN IN PLASTER' GRAHAM 'A DOZEN WHOLESALE' CHAPMAN ERIC IDLE (ACTUAL SIZE - BATTERIES EXTRA) ALSO APPEARING CAROL CLEVELAND ('FOUR REVEALING POSES' HARD PUBLICATIONS PRICE 40p) AND, IN A VARIETY OF INTERESTING POSITIONS, THE FRED TOMLINSON SINGERS UNDER THEIR LEADER 'BUTCH' TOMLINSON ROSALIND ('AFORE YE GO') BAILEY NOV AVAILABLE FROM BBC ENTERPRISES PRICE 30p AND A BOTTLE OF BELLS BODY MAKE-UP MADELAINE GAFFNEY AND THE BBC NAUGHTY LADIES' CLUB UNUSUAL COSTUMES AND LEATHERWEAR HAZEL PETHIG AND THE NAUGHTY LADS OF 'Q' DIVISION ROSTRUM CAMERA MOUNTED BY PETER WILLIS (MASSAGE IN YOUR OWN HOME OR MOTEL ROOM) ANIMATIONS AND EROTIC CARTOONS TERRY GILLIAM AND MISS HEBBERN 043-7962 GRAPHIC DETAIL BOB BLAGDEN 'DENMARK HAS NEVER LAUGHED SO MUCH' RED LIGHTING BILL BAILEY HEAVY BREATHING AND SOUND RICHARD CHUBB FILM CAMERAMAN AND 'RIK' ALAN FEATHERSTONE 'MEN IT CAN BE DONE' BLUE FILM EDITOR RAY MILLICHOPE 'WHAT YOUR RIGHT ARM'S FOR' DESIGNED BY BOB 'BIG, BLACK, BUTCH AND BEAUTIFUL' BERK PRODUCED BY IAN MCNAUGHTON WHO IS ASSISTING POLICE WITH THEIR ENQUIRIES UNE ÉMISSION NOCTURNALE PAR TÉLÉVISIONE FRANÇAISE ET BBC TV COPYRIGHT BBC TV £5 IN A PLAIN WRAPPER
| Fade out. Fade up on the BBC world symbol.
Voice Over | E. Henry Thripshaw t-shirts are now available from BBC Enterprises. The price hasn't finally been decided, and the address to write to...they haven't yet quite worked out.